import bpy
from bpy.props import (
    BoolProperty,
)
from bpy.app.handlers import persistent

import sys

from . waves import update_waves


def get_addon_version():
    addon_name = __package__
    if addon_name in bpy.context.preferences.addons:
        # Import the add-on module if it's not already
        if addon_name in sys.modules:
            addon_module = sys.modules[addon_name]
            import addon_utils
            return addon_utils.addons_fake_modules[addon_name].bl_info["version"]
            # return addon_module.bl_info.get("version")
        else:
            print(f"Module for add-on '{addon_name}' is not loaded.")
    else:
        print(f"Add-on '{addon_name}' not found or not enabled.")


@persistent
def frame_change_handler(scene, depsgraph):
    """
    Frame change handler, that redraws the ocean if and when the scene has changed.
    """
    update_waves(None, scene.context)


def update_animatable_props(self, context):
    if self.animatable_props:
        bpy.app.handlers.frame_change_post.append(frame_change_handler)
    else:
        bpy.app.handlers.frame_change_post.remove(frame_change_handler)


class POW_MT_AddonPreferences(bpy.types.AddonPreferences):
    bl_idname = __package__

    animatable_props: BoolProperty(
        name = "Animatable Properties",
        description = "Allows animationg POW properties. Current implementations has a huge performance hit.",
        default = False,
        update = update_animatable_props,
    )

    def draw(self, context):
        layout = self.layout

        box = layout.box()
        row = box.row(align = True)
        row.prop(self, "animatable_props", text="Enable animatable props:")
        row.label(text="Warning! Currently has big performance impact.", icon='ERROR')
